==> libgravatar-16.08.1-1-armv7h.pkg.tar.xz: usr/include/KF5/gravatar/gravatarconfiguresettingsdialog.h <==
/*
   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef GRAVATARCONFIGURESETTINGSDIALOG_H
#define GRAVATARCONFIGURESETTINGSDIALOG_H

#include <QDialog>
#include "gravatar_export.h"
class QCheckBox;
class QPushButton;
class KPluralHandlingSpinBox;
namespace Gravatar
{
class GRAVATAR_EXPORT GravatarConfigureSettingsDialog : public QDialog
{
    Q_OBJECT
public:
    explicit GravatarConfigureSettingsDialog(QWidget *parent = Q_NULLPTR);
    ~GravatarConfigureSettingsDialog();

private Q_SLOTS:
    void slotRestoreDefault();
    void slotClearGravatarCache();
    void save();

private:
    void load();
    QCheckBox *mUseDefaultPixmap;
    QCheckBox *mUseLibravatar;
    QCheckBox *mFallbackGravatar;
    QCheckBox *mUseHttps;
    QPushButton *mClearGravatarCache;
    KPluralHandlingSpinBox *mGravatarCacheSize;
};
}

#endif // GRAVATARCONFIGURESETTINGSDIALOG_H

==> libgravatar-18.04.2-1-armv7h.pkg.tar.xz: usr/include/KF5/gravatar/gravatarconfiguresettingsdialog.h <==
/*
   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef GRAVATARCONFIGURESETTINGSDIALOG_H
#define GRAVATARCONFIGURESETTINGSDIALOG_H

#include <QDialog>
#include "gravatar_export.h"
class QCheckBox;
class QPushButton;
class KPluralHandlingSpinBox;
namespace Gravatar {
class GRAVATAR_EXPORT GravatarConfigureSettingsDialog : public QDialog
{
    Q_OBJECT
public:
    explicit GravatarConfigureSettingsDialog(QWidget *parent = nullptr);
    ~GravatarConfigureSettingsDialog();

private:
    void slotRestoreDefault();
    void slotClearGravatarCache();
    void save();
    void load();
    QCheckBox *mUseDefaultPixmap = nullptr;
    QCheckBox *mUseLibravatar = nullptr;
    QCheckBox *mFallbackGravatar = nullptr;
    QPushButton *mClearGravatarCache = nullptr;
    KPluralHandlingSpinBox *mGravatarCacheSize = nullptr;
};
}

#endif // GRAVATARCONFIGURESETTINGSDIALOG_H
